SystemOrganization addCategory: #GODGraphGeneratorTests!

TestCase subclass: #GGGraphTest
	instanceVariableNames: 'graph dictionary'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODGraphGeneratorTests'!

GGGraphTest subclass: #GGBarGraphTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODGraphGeneratorTests'!

!GGBarGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/5/2014 10:13'!
createGraphInstance
	"Creates a instance of the line graph"

	graph := GGBarGraph new horizontalLabel: 'Estados Brasileiros'; verticalLabel: 'Altura mdia'.
	^graph! !

!GGBarGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/7/2014 00:58'!
expectedFailures
	^Array new! !

!GGBarGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/5/2014 10:14'!
fillWithDataTest: dictionary
	"Fills the dictionary with the data that will be used in the test."

	dictionary at: 'So Paulo' put: 171;
			    at: 'Rio de Janeiro' put: 169;
			    at: 'Santa Catarina' put: 174..! !

!GGGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/5/2014 10:12'!
createGraphInstance
	"Returns a new instance of the graph to be tested. Labels must be set in this method."

	^self subclassResponsibility.! !

!GGGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/7/2014 01:06'!
expectedFailures
	"This abstract class is expected to fail all tests because it does not instantiate any graph. Subclasses MUST override this method and return an empty array."
	^GGGraphTest selectors.! !

!GGGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/4/2014 23:08'!
fillWithDataTest: dictionary
	"Fills the dictionary with the data that will be used in the test."

	dictionary at: 'So Paulo' put: 171;
			    at: 'Rio de Janeiro' put: 169;
			    at: 'Santa Catarina' put: 174.! !

!GGGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/5/2014 10:32'!
setUp
	self createGraphInstance.

	dictionary := Dictionary new.
	self fillWithDataTest: dictionary.

	^graph! !

!GGGraphTest methodsFor: 'testing' stamp: 'WS 11/5/2014 10:15'!
testGenerateToFile
	"Tests the png file generation."

	graph generateGraph: dictionary toFile: 'teste'.
	self assert: ( FileDirectory default fileExists: 'teste.png' ).! !

!GGGraphTest methodsFor: 'testing' stamp: 'WS 11/5/2014 10:05'!
testHeight
	"Tests for small heights, error expected."

	self should: [ graph height: 1 ] raise: GGHeightTooSmall. 
	graph height: 15.
	self assert: graph height = 15.! !

!GGGraphTest methodsFor: 'testing' stamp: 'WS 11/12/2014 00:52'!
testHorizontalLabel
	"Tests the horizontal label. It must be a string or nil."

	self should: [ graph horizontalLabel: 1 ] raise: Error. 
	graph horizontalLabel: nil.
	self assert: graph horizontalLabel = ''.
	graph horizontalLabel: ''.
	self assert: graph horizontalLabel = ''.
	graph horizontalLabel: 'abc'.
	self assert: graph horizontalLabel = 'abc'.! !

!GGGraphTest methodsFor: 'testing' stamp: 'WS 11/19/2014 14:25'!
testOpenInWorld
	"Tests the png file generation."

	graph generateGraph: dictionary.
	graph openInWorld.
	self deny: ( ( graph currentWorld submorphIndexOf: graph ) = nil ).! !

!GGGraphTest methodsFor: 'testing' stamp: 'WS 11/12/2014 00:55'!
testVerticalLabel
	"Tests the vertical label. It must be a string or nil."

	self should: [ graph verticalLabel: 1 ] raise: Error. 
	graph verticalLabel: nil.
	self assert: graph verticalLabel = ''.
	graph verticalLabel: ''.
	self assert: graph verticalLabel = ''.
	graph verticalLabel: 'abc'.
	self assert: graph verticalLabel = 'abc'.! !

!GGGraphTest methodsFor: 'testing' stamp: 'WS 11/5/2014 10:07'!
testWidth
	"Tests for small widths, error expected."

	self should: [ graph width: 1 ] raise: GGWidthTooSmall. 
	graph width: 15.
	self assert: graph width = 15.! !

!GGGraphTest methodsFor: 'testing' stamp: 'WS 11/5/2014 10:07'!
testWidthAndHeight
	"Tests for small widths and heights, error expected."

	self should: [ graph width: 1 height: 1 ] raise: GGWidthTooSmall. 
	self should: [ graph width: 15 height: 1 ] raise: GGHeightTooSmall. 
	self should: [ graph width: 1 height: 15 ] raise: GGWidthTooSmall. 
	graph width: 15 height: 15.
	self assert: graph width = 15; assert: graph height = 15.! !

GGGraphTest subclass: #GGLineGraphTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GODGraphGeneratorTests'!

!GGLineGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/5/2014 01:54'!
createGraphInstance
	"Creates a instance of the line graph"

	graph := GGLineGraph new horizontalLabel: 'Estados Brasileiros'; verticalLabel: 'Altura mdia'.
	^graph! !

!GGLineGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/7/2014 00:59'!
expectedFailures
	^Array new! !

!GGLineGraphTest methodsFor: 'initialize-release' stamp: 'WS 11/19/2014 23:29'!
fillWithDataTest: dictionary
	"Fills the dictionary with the data that will be used in the test."

	dictionary at: 0 put: 50;
			    at: 100 put: 170;
			    at: 200 put: 150;
			    at: 300 put: 300.! !
